***"Inclusive versus Exclusive: A Cross-National Comparison of the Effects of Supranational, National, and Supranational Identity"
***By K. Amber Curtis, Clemson University, acurti2@clemson.edu
***FINAL DO-FILE; February 13, 2014
***STATA 11


***NOTE: FINAL DATASET COMPRISED OF: 
*Eurobarometer 71.3 (Papacosta, 2009; ICPSR_28184): http://www.icpsr.umich.edu/icpsrweb/ICPSR/studies/28184?q=eurobarometer+71.3&searchSource=icpsr-landing 
*Selway's (2011) measure of linguistic-religious cross-cuttingness (from "Cross-country Indices of Multidimensional Measures of Social Structure" dataset: http://thedata.harvard.edu/dvn/dv/joelselway/faces/study/StudyPage.xhtml;jsessionid=c7c0c27182be501d83b0804c6ba5?globalId=hdl:1902.1/15954&studyListingIndex=0_c7c0c27182be501d83b0804c6ba5
*Self-generated measure of country's length of EU membership (see article appendix for coding)
*Eurostat statistics on the percentage of foreign-born population in the EU27 in 2009: http://www.theguardian.com/news/datablog/2010/sep/07/immigration-europe-foreign-citizens#data


use "Inclusive v. Exclusive 2.13.14.dta", clear


***DESCRIPTIVE STATISTICS (TABLE A1); CENTER INDEPENDENT VARIABLES***
sum IAindex feeleu feelnat feelreg crimeissue thingsgood lrideol age male educ urban bornhere homeowner unempl bluecollar s_lrc c_memblength if feeleu~=. & feelnat~=. & feelreg~=. & crimeissue~=.& thingsgood~=.& lrideol~=.& age~=.& male~=.& educ~=.& urban~=.& bornhere~=.& homeowner~=.& unempl~=.& bluecollar~=.& s_lrc~=.& c_memblength~=.
mcenter feeleu feelnat feelreg crimeissue thingsgood lrideol age male educ urban bornhere homeowner unempl bluecollar s_lrc c_memblength
sum IAindex C_feeleu C_feelnat C_feelreg C_crimeissue C_thingsgood C_lrideol C_age C_male C_educ C_urban C_bornhere C_homeowner C_unempl C_bluecollar C_s_lrc C_c_memblength

***FIGURE 1***
alpha IAenrichcult IAsecurity IAempl IAneedimigs IAsolveprob IAinctol IAcontrib, item
tab IAindex
sum IAindex
sum IAindex if ccode==1
sum IAindex if ccode==2
sum IAindex if ccode==3
sum IAindex if ccode==4
sum IAindex if ccode==5
sum IAindex if ccode==6
sum IAindex if ccode==7
sum IAindex if ccode==8
sum IAindex if ccode==9
sum IAindex if ccode==10
sum IAindex if ccode==11
sum IAindex if ccode==12
sum IAindex if ccode==13
sum IAindex if ccode==14
sum IAindex if ccode==15
sum IAindex if ccode==16
sum IAindex if ccode==17
sum IAindex if ccode==18
sum IAindex if ccode==19
sum IAindex if ccode==20
sum IAindex if ccode==21
sum IAindex if ccode==22
sum IAindex if ccode==23
sum IAindex if ccode==24
sum IAindex if ccode==25
sum IAindex if ccode==26
sum IAindex if ccode==27


pwcorr feeleu feelnat feelreg, sig
factor feeleu feelnat feelreg, pcf
rotate


sum feeleu
sum feelnat
sum feelreg


***TABLE 1***
*Model 1: ANOVA
xtmixed IAindex ||ccode:, mle var
gen rho=.0130515/(.092328+.0130515)
tab rho
*Model 2: Individual-Level
xtmixed IAindex C_feeleu C_feelnat C_feelreg C_crimeissue C_thingsgood C_lrideol C_age C_male C_educ C_urban C_bornhere C_homeowner C_unempl C_bluecollar ||ccode:, mle var
*Model 3: Cross-Cuttingness
xtmixed IAindex C_feeleu C_feelnat C_feelreg C_crimeissue C_thingsgood C_lrideol C_age C_male C_educ C_urban C_bornhere C_homeowner C_unempl C_bluecollar C_s_lrc||ccode:, mle var
*Model 4: Membership
xtmixed IAindex C_feeleu C_feelnat C_feelreg C_crimeissue C_thingsgood C_lrideol C_age C_male C_educ C_urban C_bornhere C_homeowner C_unempl C_bluecollar C_c_memblength ||ccode:, mle var


***TABLE 2***
*Model 5: Cross-Cuttingness
gen feeleuXs_lrc=C_feeleu*C_s_lrc
xtmixed IAindex feeleuXs_lrc C_feeleu C_feelnat C_feelreg C_crimeissue C_thingsgood C_lrideol C_age C_male C_educ C_urban C_bornhere C_homeowner C_unempl C_bluecollar C_s_lrc||ccode: C_feeleu, mle var covar(unstructured)
*marginal effect at minimum
lincom C_feeleu+feeleuXs_lrc*-0.4919082
*marginal effect at mean
lincom C_feeleu+feeleuXs_lrc*8.67E-10
*marginal effect at maximum
lincom C_feeleu+feeleuXs_lrc*0.2570919


*Model 6: Membership
gen feeleuXmemblength=C_feeleu*C_c_memblength
xtmixed IAindex feeleuXmemblength C_feeleu C_feelnat C_feelreg C_crimeissue C_thingsgood C_lrideol C_age C_male C_educ C_urban C_bornhere C_homeowner C_unempl C_bluecollar C_c_memblength||ccode: C_feeleu, mle var covar(unstructured)
lincom C_feeleu + feeleuXmemblength*2
lincom C_feeleu + feeleuXmemblength*5
lincom C_feeleu + feeleuXmemblength*14
lincom C_feeleu + feeleuXmemblength*23
lincom C_feeleu + feeleuXmemblength*28
lincom C_feeleu + feeleuXmemblength*36
lincom C_feeleu + feeleuXmemblength*58


***TABLE 3***
*High EU: Cyprus
reg IAindex C_feeleu C_feelnat C_feelreg C_crimeissue C_thingsgood C_lrideol C_age C_male C_educ C_urban C_bornhere C_homeowner C_unempl C_bluecollar if ccode==4
xtmixed IAindex C_feeleu C_feelnat C_feelreg C_crimeissue C_thingsgood C_lrideol C_age C_male C_educ C_urban C_bornhere C_homeowner C_unempl C_bluecollar ||ccode: if ccode==4, mle var 
*High Non-EU: Latvia
reg IAindex C_feeleu C_feelnat C_feelreg C_crimeissue C_thingsgood C_lrideol C_age C_male C_educ C_urban C_bornhere C_homeowner C_unempl C_bluecollar if ccode==15
xtmixed IAindex C_feeleu C_feelnat C_feelreg C_crimeissue C_thingsgood C_lrideol C_age C_male C_educ C_urban C_bornhere C_homeowner C_unempl C_bluecollar ||ccode: if ccode==15, mle var 
*All 27 EU Members
xtmixed IAindex C_feeleu C_feelnat C_feelreg C_crimeissue C_thingsgood C_lrideol C_age C_male C_educ C_urban C_bornhere C_homeowner C_unempl C_bluecollar ||ccode:, mle var 


***FIGURES 2-7 CALCULATED IN EXCEL***
